# Nuxt-device

## Установка

1. Добавьте `@idalite-frontend:registry` в настройки глобальные настройки `npm`

```bash
npm set @idalite-frontend:registry https://git.idalite.com/api/v4/packages/npm/
```

2. Выполните команду установки пакета

```text
npm install @idalite-frontend/nuxt-device
```

3. Добавьте в tsconfig.json файл параметры для работы с типами пакета

```json
{
    "compilerOptions": {
        "typeRoots": [
            "./node_modules/@idalite-frontend",
            "./node_modules/@types"
        ]
    }
}
```

## Подключение

Необходимо подключить установленный модуль в `nuxt.config.js` файле в секции `modules`

```javascript
module.exports = {
    ...,

    modules: [
        '@idalite-frontend/nuxt-device',
    ],
};
```

## Настройка

### Предустановленные значения `breakpoints`

```json
{
    "mobile": 720,
    "tablet": 1200,
    "laptop": 1440,
    "desktop": 1920
}
```

### Изменение `breakpoints`:

1. Можно передать непосредственно в секции `modules`:

```javascript
module.exports = {
    ...,

    modules: [
        ['@idalite-frontend/nuxt-device', {
            mobile: 720,
            tablet: 1200,
            laptop: 1440,
            desktop: 1920,
        }],
    ],
};
```

2. Можно передать в параметре `nuxtDevice`:

```javascript
module.exports = {
    ...,

    modules: [
        '@idalite-frontend/nuxt-device',
    ],

    nuxtDevice: {
        mobile: 720,
        tablet: 1200,
        laptop: 1440,
        desktop: 1920,
    },
};
```

### Внимание ☝️

> Для корректной работы плагина необходимо использовать следующие ключи:
>
> `mobile`
> `tablet`
> `laptop`
> `desktop`

### Использование

Модуль создает Vue экземпляр в контексте приложения с реактивными свойствами и методами

#### Свойства:

`state` - реактивное свойство являющееся ключом по установленным `breakpoints`

`isMobile` - реактивный метод определяющий мобильную версию

```vue

<template>
    <div v-show="$device.isMobile()">Mobile</div>
</template>
```

`isTablet` - реактивный метод определяющий планшетную версию

```vue

<template>
    <div v-show="$device.isTablet()">Tablet</div>
</template>
```

`isLaptop` - реактивный метод определяющий ноутбук

```vue

<template>
    <div v-show="$device.isLaptop()">Laptop</div>
</template>
```

`isDesktop` - реактивный метод определяющий десктопную версию

```vue

<template>
    <div v-show="$device.isDesktop()">Desktop</div>
</template>
```

`is` - реактивное свойство принимающее аргументом список устройств

```vue

<template>
    <div v-show="$device.is('mobile', 'tablet')">mobile or tablet</div>
</template>
```

>
> ## Внимание 🔥🔥🔥
>
> Не стоит использовать модуль совместно с директивой `v-if`
>
> Использование условий с директивой приведет к ошибкам гидратации
>
>
