const path = require('path');

const dirs = {
    src: path.resolve(__dirname, './src'),
    dist: path.resolve(__dirname, './dist'),
};

const esbuild = require('esbuild');
const { replace } = require('esbuild-plugin-replace');
const browserslistToEsbuild = require('browserslist-to-esbuild');

const buildModule = async () => {
    try {
        await esbuild.build({
            entryPoints: [
                path.resolve(dirs.src, './index.ts'),
            ],
            outdir: dirs.dist,
            format: 'cjs',
            target: 'node14',
            plugins: [
                replace({
                    '.ts': '.js',
                }),
            ],
        });
    } catch (e) {
        console.error('BUILD_MODULE');
        console.error(e);
        process.exit(1);
    }
};

const buildPlugin = async () => {
    try {
        await esbuild.build({
            entryPoints: [
                path.resolve(dirs.src, './plugin.ts'),
                path.resolve(dirs.src, './instance.ts'),
            ],
            outdir: dirs.dist,
            external: ['vue'],
            format: 'esm',
            bundle: true,
            target: browserslistToEsbuild(),
            resolveExtensions: ['.ts', '.d.ts'],
        });
    } catch (e) {
        console.error('BUILD_PLUGIN');
        console.error(e);
        process.exit(1);
    }
};

(async function() {
    await buildModule();
    await buildPlugin();
})();
